.. _table-of-contents:

======================
Salt Table of Contents
======================

.. toctree::
    :maxdepth: 2

    topics/about_salt_project
    topics/index
    topics/salt_system_architecture
    topics/contributing-guide
    topics/installation/index
    topics/configuration/index
    topics/using_salt
    topics/execution/index
    topics/states/index
    topics/return_codes/index
    topics/utils/index
    topics/event/index
    topics/orchestrate/index
    topics/solaris/index
    topics/ssh/index
    topics/thorium/index
    topics/cloud/index
    topics/proxyminion/index
    topics/network_automation/index
    topics/virt/index
    topics/packaging/index
    ref/cli/index
    ref/pillar/index
    ref/tops/index
    ref/index
    topics/api
    topics/topology/index
    topics/cache/index
    topics/slots/index
    topics/windows/index
    topics/development/index
    topics/releases/index
    topics/venafi/index
    glossary
